@@ -27,8 +27,6 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#define UI_FILE LOGVIEW_DATADIR "/logview-filter.ui"
-
 struct _LogviewFilterManagerPrivate {
   GtkWidget *tree;
 
@@ -211,20 +209,20 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio_color))) {
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_foreground))) {
-        GdkColor foreground_color;
-        gtk_color_button_get_color (GTK_COLOR_BUTTON (color_foreground),
+        GdkRGBA foreground_color;
+        gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (color_foreground),
                                     &foreground_color);
         g_object_set (G_OBJECT (tag), 
-                      "foreground-gdk", &foreground_color,
+                      "foreground-rgba", &foreground_color,
                       "foreground-set", TRUE, NULL);
       }
 
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_background))) {
-        GdkColor background_color;
-        gtk_color_button_get_color (GTK_COLOR_BUTTON (color_background),
+        GdkRGBA background_color;
+        gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (color_background),
                                     &background_color);
         g_object_set (tag, 
-                      "paragraph-background-gdk", &background_color,
+                      "paragraph-background-rgba", &background_color,
                       "paragraph-background-set", TRUE, NULL);
       }
       
@@ -283,7 +281,7 @@ run_add_edit_dialog (LogviewFilterManager *manager, LogviewFilter *filter)
   error = NULL;
   name = NULL;
   
-  gtk_builder_add_from_file (builder, UI_FILE, &error);
+  gtk_builder_add_from_resource (builder, "/org/gnome/logview/logview-filter.ui", &error);
 
   if (error) {
     g_warning ("Could not load filter ui: %s", error->message);
@@ -347,27 +345,27 @@ run_add_edit_dialog (LogviewFilterManager *manager, LogviewFilter *filter)
     gtk_entry_set_text (GTK_ENTRY(entry_regex), regex);
 
     if (foreground_set) {
-      GdkColor *foreground;
+      GdkRGBA *foreground;
 
-      g_object_get (tag, "foreground-gdk", &foreground, NULL);
-      gtk_color_button_set_color (GTK_COLOR_BUTTON (color_foreground),
+      g_object_get (tag, "foreground-rgba", &foreground, NULL);
+      gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_foreground),
                                   foreground);
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_foreground),
                                     TRUE);
 
-      gdk_color_free (foreground);
+      gdk_rgba_free (foreground);
     }
 
     if (background_set) {
-      GdkColor *background;
+      GdkRGBA *background;
 
-      g_object_get (tag, "paragraph-background-gdk", &background, NULL);
-      gtk_color_button_set_color (GTK_COLOR_BUTTON (color_background),
+      g_object_get (tag, "paragraph-background-rgba", &background, NULL);
+      gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_background),
                                   background);
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_background),
                                     TRUE);
 
-      gdk_color_free (background);
+      gdk_rgba_free (background);
     }
 
     if (background_set || foreground_set) {
@@ -464,6 +462,7 @@ logview_filter_manager_init (LogviewFilterManager *manager)
   g_object_ref (priv->builder);
   priv->prefs = logview_prefs_get ();
 
+  gtk_window_set_default_size (GTK_WINDOW (manager), 400, -1);
   gtk_dialog_add_button (GTK_DIALOG(manager),
                          GTK_STOCK_CLOSE,
                          GTK_RESPONSE_CLOSE);
