@@ -1139,6 +1139,7 @@ action_toggle (GSimpleAction *action,
 static GActionEntry action_entries[] = {
   { "autoscroll", action_toggle, NULL, "true", action_autoscroll_change_state },
   { "search", action_toggle, NULL, "false", action_search_change_state },
+  { "gear-menu", action_toggle, NULL, "false", NULL },
   { "open", action_open, NULL, NULL, NULL },
   { "close", action_close, NULL, NULL, NULL },
   { "copy", action_copy, NULL, NULL, NULL },
@@ -1204,6 +1205,7 @@ logview_window_init (LogviewWindow *logview)
   gtk_builder_add_from_resource (builder, "/org/gnome/logview/logview-gear-menu.ui", NULL);
   menu = G_MENU_MODEL (gtk_builder_get_object (builder, "gear-menu"));
   gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (w), menu);
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (w), "win.gear-menu");
 
   priv->filters_placeholder = G_MENU_MODEL (gtk_builder_get_object (builder, "filters-placeholder"));
   g_object_unref (builder);
